package com.fs.watch.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.common.utils.StringUtils;
import com.fs.watch.domain.WatchFatigueData;
import com.fs.watch.domain.vo.WatchFatigueDataVo;
import com.fs.watch.mapper.WatchFatigueDataMapper;
import com.fs.watch.param.WatchDataQueryParam;
import com.fs.watch.service.WatchFatigueDataService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
* @author Administrator
* @description 针对表【watch_fatigue_data(设备疲劳度)】的数据库操作Service实现
* @createDate 2024-10-15 11:06:50
*/
@Service
@Slf4j
public class WatchFatigueDataServiceImpl implements WatchFatigueDataService {
    @Autowired
    private WatchFatigueDataMapper mapper;

    @Override
    public Boolean insert(WatchFatigueData watchFatigueData) {
        //判断创建时间是否唯一
        Integer num = mapper.queryByCreateTime(watchFatigueData.getCreateTime());
        if (num != null && num > 0) {
            return false;
        }
        try {
            mapper.insert(watchFatigueData);
        } catch (Exception e) {
            log.error("===============watchFatigueData:insert=========================={}", e.getMessage());
            return false;
        }
        return true;
    }

    @Override
    public List<WatchFatigueDataVo> page(WatchDataQueryParam param) {
        return mapper.page(param);
    }

    @Override
    public List<WatchFatigueDataVo> queryByDateAndDeviceId(String date, String deviceId) {
        if (StringUtils.isBlank(date)) {
            date = DateUtils.dateTimeNow("yyyy-MM-dd");
        }
        return mapper.queryByDateAndDeviceId(date,deviceId);
    }

    @Override
    public List<WatchFatigueDataVo> list(Date startTime, Date endTime, String deviceId) {
        if (StringUtils.isNotBlank(deviceId)) {
            return mapper.list(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, startTime),
                    DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, endTime),
                    deviceId);
        } else {
            return null;
        }
    }

    @Override
    public List<Map<String, Object>> countByDate(Date startTime, Date endTime, String deviceId) {
        if (StringUtils.isBlank(deviceId)) {
            return null;
        }
        //返回对象
        List<Map<String, Object>> res = null;
        res = mapper.countByDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, startTime),
                DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, endTime), deviceId);

        return res;
    }

    @Override
    public WatchFatigueData getLastByDeviceId(String deviceId) {
        return mapper.getLastByDeviceId(deviceId);
    }
}
